icometrix-sdk documentation
===========================

A library that provides a Python interface for the Icometrix API.

Quickstart
----------

.. toctree::
   :maxdepth: 2

   quickstart

Developer guide
---------------

.. toctree::
   :maxdepth: 2

   developer_guide/index


API reference
-------------

.. toctree::
   :maxdepth: 2

   resources/index


Models
------

.. toctree::
   :maxdepth: 2

   models/index